PALM-meteo: palmmeteo_stdplugins.aladin.AladinCoordTransform Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.aladin.AladinCoordTransform Class Reference
Inheritance diagram for palmmeteo_stdplugins.aladin.AladinCoordTransform:
[legend]
Collaboration diagram for palmmeteo_stdplugins.aladin.AladinCoordTransform:
[legend]

## Public Member Functions
def | __init__ (self, ncf)
def | verify (self, ncf)

## Public Attributes
| dx
| dy
| nx
| ny
| latlon_to_ji
| ji_to_latlon

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo_stdplugins.aladin.AladinCoordTransform.__init__ | ( |  | self,
|  |  | ncf
| ) |  |

## Member Function Documentation

## ◆ verify()

def palmmeteo_stdplugins.aladin.AladinCoordTransform.verify | ( |  | self,
|  |  | ncf
| ) |  |

## Member Data Documentation

## ◆ dx

palmmeteo_stdplugins.aladin.AladinCoordTransform.dx

## ◆ dy

palmmeteo_stdplugins.aladin.AladinCoordTransform.dy

## ◆ ji_to_latlon

palmmeteo_stdplugins.aladin.AladinCoordTransform.ji_to_latlon

## ◆ latlon_to_ji

palmmeteo_stdplugins.aladin.AladinCoordTransform.latlon_to_ji

## ◆ nx

palmmeteo_stdplugins.aladin.AladinCoordTransform.nx

## ◆ ny

palmmeteo_stdplugins.aladin.AladinCoordTransform.ny

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/aladin.py